
# Type: subclass_of


rdfs:subClassOf to be emitted in OWL generation

URI: [meta:subclass_of](https://w3id.org/biolink/biolinkml/meta/subclass_of)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>OPT</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:subClassOf |

